pyMolDyn
########


pyMolDyn is a viewer for atomic clusters, crystalline and amorphous materials in a unit cell corresponding to one of
the seven 3D Bravais lattices. The program calculates cavities (vacancies, voids) according to three definitions.

.. image:: http://pgi-jcns.fz-juelich.de/portal/static/images/pymoldyn-gui.png
    :width: 80%
    :alt: pyMolDyn GUI
    :align: center

Features
========

-   Interactive viewer based on GR3
-   Computation of cavities in all seven 3D Bravais lattice systems
-   Creation of high resolution images appropriate for publications
-   Video creation from a set of input frames to analyze cavity changes in materials over time
-   Statistics including

    -   Surfaces, volumes and surface volume ratios of cavities and domains
    -   Pair distribution functions (including cavities), bonds, bond (dihedral) angles
    -   Gyration tensor, asphericity, acylindricity

-   Filter for atoms and cavities
-   Batch mode for simultaneous processing of multiple files


Documentation
=============

Further information on supported input formats and the bravais lattice systems can be found on the
`pyMolDyn documentation page <https://pgi-jcns.fz-juelich.de/portal/pages/pymoldyn-doc.html>`_.

`A quick introduction to the gui version <https://pgi-jcns.fz-juelich.de/portal/pages/pymoldyn-gui.html>`_ is also
available.


Download
========

We provide binary software packages for Linux and Mac OS X at our
`pyMolDyn homepage <https://pgi-jcns.fz-juelich.de/portal/pages/pymoldyn-main.html>`_.


Contact
=======

For questions, bug reports or feature requests please contact `Ingo Meyer <mailto:i.meyer@fz-juelich.de>`_
(software maintainer).
